# Python script to show GPS locations of the photos inside a directory on a map
# https://pge.bvsoft.be


import os
import glob
import webbrowser
from PIL import Image
from PIL.ExifTags import TAGS, GPSTAGS
import folium

# Function to extract GPS coordinates from an image's EXIF data
def get_gps_coordinates(image_path):
    try:
        image = Image.open(image_path)
        exif_data = image._getexif()

        if not exif_data:
            return None

        gps_info = exif_data.get(34853)  # Key for 'GPSInfo' in EXIF

        if not gps_info:
            return None

        def convert_to_degrees(value):
            d, m, s = value
            return d + (m / 60.0) + (s / 3600.0)

        lat_data = gps_info.get(2)
        lon_data = gps_info.get(4)

        if lat_data and lon_data:
            lat = convert_to_degrees(lat_data)
            lon = convert_to_degrees(lon_data)
            if gps_info.get(1) == 'S':
                lat = -lat
            if gps_info.get(3) == 'W':
                lon = -lon
            return lat, lon
    except Exception as e:
        print(f"An error occurred: {e}")
    return None

def create_map_html(output_file, coordinates):
    # Generate HTML file with a map containing all coordinates
    map_obj = folium.Map()
    bounds = []
    for coord in coordinates:
        marker = folium.Marker(coord)
        marker.add_to(map_obj)
        bounds.append(coord)

    # Fit the map to the bounds
    if bounds:
        map_obj.fit_bounds(bounds)

    map_obj.save(output_file)
    return output_file

def main():
    # Use current working directory
    cwd = os.getcwd()
    
    # Find all JPG files
    jpg_files = glob.glob(os.path.join(cwd, "*.jpg"))
    coordinates = []

    # Extract GPS coordinates from each JPG file
    for jpg_file in jpg_files:
        gps_coords = get_gps_coordinates(jpg_file)
        if gps_coords:
            coordinates.append(gps_coords)

    if coordinates:
        # File to save the HTML map
        resultCount = len(coordinates)
        print(f"{resultCount} GPS coordinates detected")
		
        output_file = "photo_locations.html"
        html_file_path = create_map_html(output_file, coordinates)
        
        # Open the HTML file in the default web browser
        webbrowser.open(html_file_path)
        print(f"Map created and opened in browser: {html_file_path}")
    else:
        print("No GPS data found in this folder.")

if __name__ == "__main__":
    main()
